module org.graalvm.nativeimage.pointsto {
    requires java.management;
    requires jdk.graal.compiler;
    requires jdk.internal.vm.ci;
    requires jdk.management;
    requires org.graalvm.collections;
    requires org.graalvm.nativeimage;
    requires org.graalvm.nativeimage.base;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.graal.pointsto;
    exports com.oracle.graal.pointsto.api;
    exports com.oracle.graal.pointsto.constraints;
    exports com.oracle.graal.pointsto.flow;
    exports com.oracle.graal.pointsto.flow.builder;
    exports com.oracle.graal.pointsto.flow.context.bytecode;
    exports com.oracle.graal.pointsto.flow.context.object;
    exports com.oracle.graal.pointsto.heap;
    exports com.oracle.graal.pointsto.heap.value;
    exports com.oracle.graal.pointsto.infrastructure;
    exports com.oracle.graal.pointsto.meta;
    exports com.oracle.graal.pointsto.nodes;
    exports com.oracle.graal.pointsto.phases;
    exports com.oracle.graal.pointsto.reports;
    exports com.oracle.graal.pointsto.results;
    exports com.oracle.graal.pointsto.typestate;
    exports com.oracle.graal.pointsto.util;

    provides OptionDescriptors with AnalysisReportsOptions_OptionDescriptors, StrengthenGraphs_OptionDescriptors, PointstoOptions_OptionDescriptors, HeapSnapshotVerifier_OptionDescriptors, InlineBeforeAnalysis_OptionDescriptors;

}

